@@ -32,20 +32,16 @@ plot.cluspca<-function(x, dims = c(1,2), disp = TRUE, cludesc = FALSE, what = c(
   
   #pdf(file=paste("K",deparse(K),"Mapunits.pdf",sep=""),height=9 , width=9)
   
-  xallmax=max(max(x$attcoord[,dim1]),max(x$obscoord[,dim1]))
-  xallmin=min(min(x$attcoord[,dim1]),min(x$obscoord[,dim1]))
-  yallmax=max(max(x$attcoord[,dim2]),max(x$obscoord[,dim2]))
-  yallmin=min(min(x$attcoord[,dim2]),min(x$obscoord[,dim2]))
   x_all_range=xallmax-xallmin
   y_all_range=yallmax-yallmin
   all_range=max(x_all_range,y_all_range)
   xallmax=xallmin+all_range
   yallmax=yallmin+all_range
   # extend borders to show all points
-  xallmax = xallmax + 0.01*all_range
-  xallmin = xallmin - 0.01*all_range
-  yallmax = yallmax + 0.01*all_range
-  yallmin = yallmin - 0.01*all_range
+ # xallmax = xallmax + 0.05*all_range
+#  xallmin = xallmin - 0.05*all_range
+#  yallmax = yallmax + 0.05*all_range
+#  yallmin = yallmin - 0.05*all_range
   #
   xattmax=max(x$attcoord[,dim1])
   xattmin=min(x$attcoord[,dim1])
@@ -75,11 +71,11 @@ plot.cluspca<-function(x, dims = c(1,2), disp = TRUE, cludesc = FALSE, what = c(
     a=a+geom_point(aes(x=d1,y=d2,colour=gr,shape=gr,alpha=.4),size=1)+theme_bw()
     #do not show obs labels if more than 30
     if (dim(x$odata)[1] < 30) {
-      a=a+geom_text_repel(data=obs_df,aes(label=olab))
+      a=a+geom_text(data=obs_df,aes(label=olab))
     }
     a=a+theme(legend.position="none",axis.text.x = element_blank(),axis.text.y = element_blank())+xlab("")+ylab("")
     a=a+geom_point(data=group_df,aes(x=d1,y=d2,shape=gr))+theme(legend.position="none",axis.text.x = element_blank(),axis.text.y = element_blank())
-    a=a+geom_text_repel(data=group_df,aes(label=glab))
+    a=a+geom_text(data=group_df,aes(label=glab))
     a=a+geom_vline(xintercept=0)+geom_hline(yintercept=0)
     
     if(disp==F){ggsave(filename = paste("K",deparse(K),"Map_units.pdf",sep=""),a,height=8 , width=8)
@@ -90,11 +86,7 @@ plot.cluspca<-function(x, dims = c(1,2), disp = TRUE, cludesc = FALSE, what = c(
     
   }
   if(what[1]==FALSE && what[2]==TRUE ){
-    
-    # xallmax=xattmax
-    # xallmin=xattmin
-    # yallmax=yattmax
-    # yallmin=yattmin
+  
     
     xallmax=1
     xallmin=-1
@@ -108,15 +100,13 @@ plot.cluspca<-function(x, dims = c(1,2), disp = TRUE, cludesc = FALSE, what = c(
       mysize=max(2,mysize)
     }else{mysize=5}
     
-    a=ggplot(data=att_df,aes(x=d1,y=d2))+xlim(xallmin,xallmax)+ylim(yallmin,yallmax)
+    a=ggplot(data=att_df,aes(x=d1,y=d2))#+xlim(xallmin,xallmax)+ylim(yallmin,yallmax)
     a=a+geom_point(alpha=.5,size=.25)+theme_bw()+xlab("")+ylab("")
-    a=a+geom_text_repel(data=subset(att_df,act=="outer"),aes( label = attnam),size=mysize,segment.size = 0.1)
+    a=a+geom_text(data=subset(att_df,act=="outer"),aes( label = attnam),size=mysize)#,segment.size = 0.1)
     a=a+geom_text(data=subset(att_df,act!="outer"),aes( label = attnam),size=mysize*.8)
     a=a+geom_segment(data=att_df, aes(x=0,y=0,xend=d1,yend=d2),arrow=arrow(angle=15,unit(0.15, "inches")))
     a=a+annotate("path",x=0+1*cos(seq(0,2*pi,length.out=100)),
                  y=0+1*sin(seq(0,2*pi,length.out=100)))
-    # a=a+geom_point(data=group_df,aes(x=d1,y=d2,shape=gr))+theme(legend.position="none",axis.text.x = element_blank(),axis.text.y = element_blank())
-    # a=a+geom_text_repel(data=group_df,aes(label=glab))
     a=a+geom_vline(xintercept=0)+geom_hline(yintercept=0)
     if(disp==F){
       ggsave(filename = paste("K",deparse(K),"Map_attributes.pdf",sep=""),a,height=8 , width=8)
@@ -134,18 +124,28 @@ plot.cluspca<-function(x, dims = c(1,2), disp = TRUE, cludesc = FALSE, what = c(
     }else{mysize=5}
     
     
-    a=ggplot(data=obs_df,aes(x=d1,y=d2))+xlim(xallmin,xallmax)+ylim(yallmin,yallmax)
+    a=ggplot(data=obs_df,aes(x=d1,y=d2))#+xlim(xallmin,xallmax)+ylim(yallmin,yallmax)
     a=a+geom_point(aes(x=d1,y=d2,shape=gr,alpha=.4),size=1)+theme_bw()#,colour=gr
     #do not show obs labels if more than 30
     if (dim(x$odata)[1] < 30) {
-      a=a+geom_text_repel(data=obs_df,aes(label=olab))
+      a=a+geom_text(data=obs_df,aes(label=olab))
     }
     a=a+theme(axis.text.x = element_blank(),axis.text.y = element_blank())+xlab("")+ylab("")
     a=a+geom_point(data=group_df,aes(x=d1,y=d2,shape=gr))
-    a=a+geom_text_repel(data=group_df,aes(label=glab))
+    a=a+geom_text(data=group_df,aes(label=glab))
     a=a+geom_vline(xintercept=0)+geom_hline(yintercept=0)
+  
+   # yallmin=ggplot_build(a)$panel$ranges[[1]]$y.range[1]
+  #  yallmax=ggplot_build(a)$panel$ranges[[1]]$y.range[2]
+  #  xallmin=ggplot_build(a)$panel$ranges[[1]]$x.range[1]
+  #  xallmax=ggplot_build(a)$panel$ranges[[1]]$x.range[2]
     att_df$slp=att_df$d2/att_df$d1
-    
+  
+    #fix bug 09.11.16 (if slope is INF replace with att_df$d2/almost zero)
+    if (any(is.infinite(att_df$slp)) == TRUE) {
+      att_df$slp[which(is.infinite(att_df$slp))] = att_df$d2[which(is.infinite(att_df$slp))]/0.000001
+    }
+     
     # arrow_df=data.frame(slp=att_df$slp)
     quad_check=sign(att_df[,1:2])
     marg_df=quad_check
@@ -181,15 +181,16 @@ plot.cluspca<-function(x, dims = c(1,2), disp = TRUE, cludesc = FALSE, what = c(
     }
     
     myarrow_df$attnam=att_df$attnam
-    
     a=a+geom_abline(data=att_df,aes(intercept=0,slope=slp,colour=attnam),alpha=.5)
     a=a+geom_segment(data=myarrow_df,aes(x=0,y=0,xend=d1,yend=d2,colour=attnam),alpha=.5,
                                         arrow=arrow(length=unit(.15,"inches")))
     
     a=a+theme(legend.title=element_blank(),legend.position="none",axis.text.x = element_blank(),axis.text.y = element_blank())
-     a=a+guides(shape=FALSE,alpha=FALSE)
+    a=a+guides(shape=FALSE,alpha=FALSE)
+    
+    a=a+geom_text(data=myarrow_df,aes(x=d1,y=d2,label=attnam))
+    
     
-     a=a+geom_text_repel(data=myarrow_df,aes(x=d1,y=d2,label=attnam))
     
     if(disp==FALSE){
       ggsave(filename = paste("K",deparse(K),"Map.pdf",sep=""),a,height=8 , width=8)
